@@ -20,8 +20,9 @@ from pygments.formatter import Formatter
 
 from .pyqt import QtCore, QtGui, QtWidgets, getSaveFileName
 
+from .datadialogs import NXPanel, NXTab
 from .utils import confirm_action
-from .widgets import NXLabel, NXLineEdit
+from .widgets import NXLabel, NXLineEdit, NXPushButton
 
 
 def hex2QColor(c):
@@ -92,12 +93,11 @@ class NXScrollBar(QtWidgets.QScrollBar):
         if (self.signalsBlocked() and 
             change == QtWidgets.QAbstractSlider.SliderValueChange):
             self.blockSignals(False)
-        
 
 
 class NXPlainTextEdit(QtWidgets.QPlainTextEdit):
 
-    def __init__(self, parent):
+    def __init__(self, slot=None, parent=None):
         super(NXPlainTextEdit, self).__init__()
         self.setFont(QtGui.QFont('Courier'))
         self.setMinimumWidth(700)
@@ -108,6 +108,8 @@ class NXPlainTextEdit(QtWidgets.QPlainTextEdit):
         self.blockCountChanged.connect(parent.update_line_numbers)
         self.scrollbar = NXScrollBar(self)
         self.setVerticalScrollBar(self.scrollbar)
+        if slot:
+            self.scrollbar.valueChanged.connect(slot)
 
     def __repr__(self):
         return 'NXPlainTextEdit()'
@@ -117,63 +119,34 @@ class NXPlainTextEdit(QtWidgets.QPlainTextEdit):
         return self.blockCount()
 
        
-class NXScriptWindow(QtWidgets.QDialog):
+class NXScriptWindow(NXPanel):
 
     def __init__(self, parent=None):
-        super(NXScriptWindow, self).__init__(parent)
-        layout = QtWidgets.QVBoxLayout()
-        self.tabs = QtWidgets.QTabWidget(self)
-        layout.addWidget(self.tabs)
-        self.setLayout(layout)
-        self.setWindowTitle('Script Editor')
-        self.tabs.currentChanged.connect(self.update)
+        super(NXScriptWindow, self).__init__('Editor', title='Script Editor',
+                                             close=False, parent=parent)
+        self.tab_class = NXScriptEditor
 
     def __repr__(self):
         return 'NXScriptWindow()'
 
-    @property
-    def editors(self):
-        return [self.tabs.widget(idx) for idx in range(self.tabs.count())]
-
-    @property
-    def editor(self):
-        return self.tabs.currentWidget()
-
-    def update(self):
-        for editor in self.editors:
-            editor.adjustSize()
-        if self.tabs.count() == 0:
-            self.setVisible(False)
-
-    def closeEvent(self, event):
-        self.close()
-        event.accept()
-        
-    def close(self):
-        self.editor.close()
-        if self.tabs.count() == 0:
-            self.setVisible(False)
+    def activate(self, file_name):
+        if file_name:
+            label = os.path.basename(file_name)
+        else:
+            label = 'Untitled %s' % (self.count+1)
+        super(NXScriptWindow, self).activate(label, file_name)
 
 
-class NXScriptEditor(QtWidgets.QWidget):
+class NXScriptEditor(NXTab):
     """Dialog to plot arbitrary NeXus data in one or two dimensions"""
  
-    def __init__(self, file_name=None, parent=None):
+    def __init__(self, label, file_name=None, parent=None):
 
-        if parent is None:
-            from .consoleapp import _mainwindow
-            self.mainwindow = _mainwindow
-        else:
-            self.mainwindow = parent
-        self.window = self.mainwindow.editors
-
-        QtWidgets.QWidget.__init__(self, parent=self.window.tabs)
+        super(NXScriptEditor, self).__init__(label, parent=parent)
  
         self.file_name = file_name
         self.default_directory = self.mainwindow.script_dir
 
-        layout = QtWidgets.QVBoxLayout()
-        self.text_layout = QtWidgets.QHBoxLayout()
         self.number_box = QtWidgets.QPlainTextEdit('1')
         self.number_box.setFont(QtGui.QFont('Courier'))
         self.number_box.setStyleSheet(
@@ -184,61 +157,37 @@ class NXScriptEditor(QtWidgets.QWidget):
         self.number_box.setHorizontalScrollBarPolicy(
             QtCore.Qt.ScrollBarAlwaysOff)
         self.number_box.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
-        self.text_layout.addWidget(self.number_box)
-        self.text_box = NXPlainTextEdit(self)
-        self.text_box.scrollbar.valueChanged.connect(self.scroll_numbers)
-        self.text_layout.addWidget(self.text_box)
+        self.text_box = NXPlainTextEdit(slot=self.scroll_numbers,
+                                        parent=self)
+        self.text_layout = self.make_layout(self.number_box, self.text_box,
+                                            align='justified')
         self.text_layout.setSpacing(0)
-        layout.addLayout(self.text_layout)
         
-        run_button = QtWidgets.QPushButton('Run Script')
-        run_button.clicked.connect(self.run_script)
-        run_button.setAutoDefault(False)
-        self.argument_box = NXLineEdit()
-        self.argument_box.setMinimumWidth(200)
-        save_button = QtWidgets.QPushButton('Save')
-        save_button.clicked.connect(self.save_script)
-        save_as_button = QtWidgets.QPushButton('Save as...')
-        save_as_button.clicked.connect(self.save_script_as)
-        self.delete_button = QtWidgets.QPushButton('Delete')
-        self.delete_button.clicked.connect(self.delete_script)
-        close_button = QtWidgets.QPushButton('Close Tab')
-        close_button.clicked.connect(self.close)
-        button_layout = QtWidgets.QHBoxLayout()
-        button_layout.addWidget(run_button)
-        button_layout.addWidget(self.argument_box)
-        button_layout.addStretch()
-        button_layout.addWidget(save_button)
-        button_layout.addWidget(save_as_button)
-        button_layout.addWidget(self.delete_button)
-        button_layout.addWidget(close_button)
-        layout.addLayout(button_layout)
-        self.setLayout(layout)
+        run_button = NXPushButton('Run Script', self.run_script)
+        self.argument_box = NXLineEdit(width=200)
+        save_button = NXPushButton('Save', self.save_script)
+        save_as_button = NXPushButton('Save as...', self.save_script_as)
+        self.delete_button = NXPushButton('Delete', self.delete_script)
+        close_button = NXPushButton('Close Tab', self.panel.close)
+        button_layout = self.make_layout(run_button, self.argument_box,
+                                         'stretch', 
+                                         save_button, save_as_button,
+                                         self.delete_button, close_button)
+        self.set_layout(self.text_layout, button_layout)
 
         if self.file_name:
-            self.label = os.path.basename(self.file_name)
             with open(self.file_name, 'r') as f:
                 text = f.read()
             self.text_box.setPlainText(text)
-            self.window.tabs.addTab(self, self.label)
             self.update_line_numbers()
         else:
-            self.label = 'Untitled %s' % (self.window.tabs.count()+1)
             self.delete_button.setVisible(False)
-            self.window.tabs.addTab(self, self.label)
-        self.index = self.window.tabs.indexOf(self)
-
-        self.window.tabs.adjustSize()
-        self.window.tabs.setCurrentWidget(self)
 
         self.hl = Highlighter(self.text_box.document())
 
         self.text_box.setFocus()
         self.number_box.setFocusPolicy(QtCore.Qt.NoFocus)
 
-    def __repr__(self):
-        return 'NXScriptEditor(%s)' % self.label
-        
     def get_text(self):
         text = self.text_box.document().toPlainText().strip()
         return text.replace('\t', '    ')+'\n'
@@ -283,8 +232,7 @@ class NXScriptEditor(QtWidgets.QWidget):
             with open(file_name, 'w') as f:
                 f.write(self.get_text())
             self.file_name = file_name
-            self.window.tabs.setTabText(self.index, 
-                                        os.path.basename(self.file_name))
+            self.tab_label = os.path.basename(self.file_name)
             self.mainwindow.add_script_action(self.file_name)
             self.delete_button.setVisible(True)
 
@@ -295,9 +243,4 @@ class NXScriptEditor(QtWidgets.QWidget):
                     "This cannot be reversed"):
                 os.remove(self.file_name)
                 self.mainwindow.remove_script_action(self.file_name)
-                self.close()
-
-    def close(self):
-        self.window.tabs.removeTab(self.index)
-        self.deleteLater()
-        self.window.update()
+                self.panel.close()
