@@ -101,13 +101,9 @@ class ImportDialog(BaseImportDialog):
         rangebox = QtWidgets.QWidget()
         layout = QtWidgets.QHBoxLayout()
         rangeminlabel = NXLabel("Min. index")
-        self.rangemin = NXLineEdit()
-        self.rangemin.setFixedWidth(150)
-        self.rangemin.setAlignment(QtCore.Qt.AlignRight)
+        self.rangemin = NXLineEdit(width=150, align='right')
         rangemaxlabel = NXLabel("Max. index")
-        self.rangemax = NXLineEdit()
-        self.rangemax.setFixedWidth(150)
-        self.rangemax.setAlignment(QtCore.Qt.AlignRight)
+        self.rangemax = NXLineEdit(width=150, align='right')
         layout.addWidget(rangeminlabel)
         layout.addWidget(self.rangemin)
         layout.addStretch()
