@@ -17,8 +17,6 @@ from __future__ import (absolute_import, division, print_function,
 
 import numpy as np
 
-from nexpy.gui.pyqt import QtGui
-
 from nexusformat.nexus import *
 from nexpy.gui.importdialog import BaseImportDialog
 
@@ -31,10 +29,7 @@ class ImportDialog(BaseImportDialog):
 
         super(ImportDialog, self).__init__(parent)
         
-        layout = QtGui.QVBoxLayout()
-        layout.addLayout(self.filebox())
-        layout.addWidget(self.buttonbox())
-        self.setLayout(layout)
+        self.set_layout(self.filebox(), self.buttonbox())
   
         self.setWindowTitle("Import "+str(filetype))
  
